{% load i18n %}
{% load lfc_tags %}

<form action="{% url lfc_save_seo obj.id %}"
      method="POST">
    <table>
        {% include "lfc/manage/lfc_form.html" %}
    </table>

    {% ifhasperm edit %}
        <input class="ajax-save-button"
               type="submit"
               value="{% trans 'Save SEO' %}" />
    {% endifhasperm %}

</form>
